==> flutter_bl_umpush-0.0.2.tar.gz: example/android/app/src/main/java/com/example/flutter_bl_umpush_example/MainActivity.java <==

import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import com.honghu.topsports.Event.ReceiveUmPushEvent;
import com.honghu.topsports.Event.RegistUmPushEvent;
import com.honghu.topsports.umeng.FlutterBlUmpushPlugin;
import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;
import org.greenrobot.eventbus.ThreadMode;

import java.lang.reflect.Field;
import java.lang.reflect.Method;

import io.flutter.app.FlutterActivity;
import io.flutter.plugins.GeneratedPluginRegistrant;

public class MainActivity extends FlutterActivity {

    private static final String TAG = "MainActivity";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        GeneratedPluginRegistrant.registerWith(this);
        FlutterBlUmpushPlugin.registerWith(this.registrarFor("包名.FlutterBlUmpushPlugin"));
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    public void onReceiveMsg(RegistUmPushEvent event) {
        sendDeviceToken();
    }

    private void sendDeviceToken() {
        // 传DeviceToken
        FlutterBlUmpushPlugin.channel.invokeMethod("callbackDeviceToken", MyApplication.myDeviceToken);
        Log.i(TAG, "'callbackDeviceToken' 调用成功！deviceToken:" + MyApplication.myDeviceToken);
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    public void onReceiveMsg(ReceiveUmPushEvent event) {
        FlutterBlUmpushPlugin.channel.invokeMethod("openNotification", event.getMessage());
        Log.i(TAG, "onReceiveMsg: 回传消息 -> url:" + event.getMessage().get("url")
                + " redirectType:" + event.getMessage().get("redirectType"));
    }

    /**
     * 华为角标设置
     * @param count
     */
    public void setBadgeNum(int count) {
        try {
            Bundle bundle = new Bundle();
            bundle.putString("package", getPackageName()); // com.test.badge is your package name
            bundle.putString("class", getPackageName() + ".MainActivity"); // com.test. badge.MainActivity is your apk main activity
            bundle.putInt("badgenumber", count);
            this.getContentResolver().call(Uri.parse("content://com.huawei.android.launcher.settings/badge/"),
                    "change_badge", null, bundle);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 三星角标设置
     * @param count   count
     */
    private void setBadgeOfSumsung(int count) {
        Intent intent = new Intent("android.intent.action.BADGE_COUNT_UPDATE");
        intent.putExtra("badge_count", count);
        intent.putExtra("badge_count_package_name", getPackageName());
        intent.putExtra("badge_count_class_name", getPackageName() + ".MainActivity");
        sendBroadcast(intent);
    }

    @Override
    protected void onStart() {
        super.onStart();
        EventBus.getDefault().register(this);
        setBadgeNum(0);
        setBadgeOfSumsung(0);
    }

    @Override
    protected void onResume() {
        super.onResume();
        setBadgeNum(0);
        setBadgeOfSumsung(0);
    }

    @Override
    protected void onStop() {
        super.onStop();
        EventBus.getDefault().unregister(this);
        setBadgeNum(0);
        setBadgeOfSumsung(0);
    }
}

==> flutter_bl_umpush-0.0.7.tar.gz: example/android/app/src/main/java/com/example/flutter_bl_umpush_example/MainActivity.java <==
package com.example.flutter_bl_umpush_example;

import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;

import com.example.flutter_bl_umpush_example.Event.ReceiveUmPushEvent;
import com.example.flutter_bl_umpush_example.Event.RegistUmPushEvent;
import com.example.flutter_bl_umpush_example.umeng.FlutterBlUmpushPlugin;

import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;
import org.greenrobot.eventbus.ThreadMode;

import java.util.Map;

import io.flutter.app.FlutterActivity;
import io.flutter.plugins.GeneratedPluginRegistrant;

public class MainActivity extends FlutterActivity {

    private static final String TAG = "MainActivity";
    private Handler mHandler;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        GeneratedPluginRegistrant.registerWith(this);
        FlutterBlUmpushPlugin.registerWith(this.registrarFor("com.example.flutter_bl_umpush_example.umeng.FlutterBlUmpush"));

        mHandler = new Handler() {
            @Override
            public void handleMessage(Message msg) {
                super.handleMessage(msg);

                FlutterBlUmpushPlugin.channel.invokeMethod("openNotification", msg.obj);
                Log.i(TAG, "MainActivity: 发送打开消息：" + msg.obj.toString());
                // 发送Event
//                ReceiveUmPushEvent receiveUmPushEvent = new ReceiveUmPushEvent(0, map);
//                EventBus.getDefault().post(receiveUmPushEvent);
            }
        };

        Intent intent = getIntent();
        if (null != intent) {
            Map map = (Map) intent.getSerializableExtra("map");
            if (null != map) {
                Message message = Message.obtain();
                message.obj = map;
                mHandler.sendMessageDelayed(message, 3000);
            }
        }
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    public void onReceiveMsg(RegistUmPushEvent event) {
        sendDeviceToken();
    }

    private void sendDeviceToken() {
        // 传DeviceToken
        FlutterBlUmpushPlugin.channel.invokeMethod("callbackDeviceToken", MyApplication.myDeviceToken);
        Log.i(TAG, "'callbackDeviceToken' 调用成功！deviceToken:" + MyApplication.myDeviceToken);
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    public void onReceiveMsg(ReceiveUmPushEvent event) {
        FlutterBlUmpushPlugin.channel.invokeMethod("openNotification", event.getMessage());
        Log.i(TAG, "onReceiveMsg: 回传消息 -> url:" + event.getMessage().get("url")
                + " redirectType:" + event.getMessage().get("redirectType"));
    }

    /**
     * 华为角标设置
     *
     * @param count
     */
    public void setBadgeNum(int count) {
        try {
            Bundle bundle = new Bundle();
            bundle.putString("package", getPackageName()); // com.test.badge is your package name
            bundle.putString("class", getPackageName() + ".MainActivity"); // com.test. badge.MainActivity is your apk main activity
            bundle.putInt("badgenumber", count);
            this.getContentResolver().call(Uri.parse("content://com.huawei.android.launcher.settings/badge/"),
                    "change_badge", null, bundle);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 三星角标设置
     *
     * @param count count
     */
    private void setBadgeOfSumsung(int count) {
        Intent intent = new Intent("android.intent.action.BADGE_COUNT_UPDATE");
        intent.putExtra("badge_count", count);
        intent.putExtra("badge_count_package_name", getPackageName());
        intent.putExtra("badge_count_class_name", getPackageName() + ".MainActivity");
        sendBroadcast(intent);
    }

    @Override
    protected void onStart() {
        super.onStart();
        EventBus.getDefault().register(this);
        setBadgeNum(0);
        setBadgeOfSumsung(0);
    }

    @Override
    protected void onResume() {
        super.onResume();
        setBadgeNum(0);
        setBadgeOfSumsung(0);
    }

    @Override
    protected void onStop() {
        super.onStop();
        EventBus.getDefault().unregister(this);
        setBadgeNum(0);
        setBadgeOfSumsung(0);
    }

    /**
     * 获取渠道
     */
    private String getChannel() {
        try {
            PackageManager pm = getPackageManager();
            ApplicationInfo appInfo = pm.getApplicationInfo(getPackageName(), PackageManager.GET_META_DATA);
            return appInfo.metaData.getString("UMENG_CHANNEL");
        } catch (PackageManager.NameNotFoundException ignored) {
        }
        return "";
    }
}
